pub struct CreateMessageParams {
pub messages: Vec<SamplingMessage>,
pub model_preferences: Option<ModelPreferences>,
pub system_prompt: Option<String>,
pub include_context: Option<IncludeContext>,
pub temperature: Option<f64>,
pub max_tokens: i64,
pub stop_sequences: Option<Vec<String>>,
pub metadata: Option<Value>,
}Fields
messages: Vec<SamplingMessage>model_preferences: Option<ModelPreferences>The server’s preferences for which model to select. The client MAY ignore these preferences.
system_prompt: Option<String>An optional system prompt the server wants to use for sampling. The client MAY modify or omit this prompt.
include_context: Option<IncludeContext>A request to include context from one or more MCP servers (including the caller), to be attached to the prompt. The client MAY ignore this request.
temperature: Option<f64>max_tokens: i64The maximum number of tokens to sample, as requested by the server. The client MAY choose to sample fewer tokens than requested.
stop_sequences: Option<Vec<String>>metadata: Option<Value>Optional metadata to pass through to the LLM provider. The format of this metadata is provider-specific.