CreateMessageResult

Struct CreateMessageResult 

pub struct CreateMessageResult {
    pub role: Role,
    pub content: SamplingContent,
    pub model: String,
    pub stop_reason: Option<StopReason>,
    pub result: Result,
}
The client’s response to a sampling/create_message request from the server. The client should inform the user before returning the sampled message, to allow them to inspect the response (human in the loop) and decide whether to allow the server to see it.

Fields

role: Rolecontent: SamplingContentmodel: String

The name of the model that generated the message.

stop_reason: Option<StopReason>

The reason why sampling stopped, if known.

result: Result