pub struct PromptListChangedNotification {
pub method: String,
}Expand description
An optional notification from the server to the client, informing it that the list of prompts it offers has changed. This may be issued by servers without any previous subscription from the client.
Fields
method: StringTrait Implementations
Sourceimpl Clone for PromptListChangedNotification
impl Clone for PromptListChangedNotification
Sourcefn clone(&self) -> PromptListChangedNotification
fn clone(&self) -> PromptListChangedNotification
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for PromptListChangedNotification
impl<'de> Deserialize<'de> for PromptListChangedNotification
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more